@@ -83,7 +83,7 @@ void CECController::handleCompleteEvent(const int keycode, const int keyduration
 
 CECController::CECController()
 {
-    QDBusConnection::sessionBus().registerService("org.kde.plasma-remotecontrollers");
+    QDBusConnection::sessionBus().registerService("org.kde.plasma.remotecontrollers");
     QDBusConnection::sessionBus().registerObject("/CEC", this, QDBusConnection::ExportScriptableSlots);
 
     QObject::connect(this, &CECController::keyPress,
@@ -134,7 +134,7 @@ CECController::CECController()
     libcec_configuration cecConfig;
     cecConfig.Clear();
     cecConfig.bActivateSource = 0;
-    snprintf(cecConfig.strDeviceName, LIBCEC_OSD_NAME_SIZE, "%s", qPrintable(i18n("KDE Plasma")));
+    snprintf(cecConfig.strDeviceName, LIBCEC_OSD_NAME_SIZE, "%s", qPrintable(generalGroup.readEntry("OSDName", i18n("KDE Plasma"))));
     cecConfig.clientVersion = LIBCEC_VERSION_CURRENT;
     cecConfig.deviceTypes.Add(CEC_DEVICE_TYPE_RECORDING_DEVICE);
     cecConfig.callbacks = &m_cecCallbacks;
@@ -175,6 +175,7 @@ void CECController::discoverDevices() {
 
         // TODO: detect and handle disconnects
         Device* device = new Device(DeviceCEC, "CEC Controller", devices[i].strComName);
+        device->setUsedKeys(QSet<int>(m_keyCodeTranslation.cbegin(), m_keyCodeTranslation.cend()));
         ControllerManager::instance().newDevice(device);
     }
 }
@@ -214,3 +215,27 @@ bool CECController::hdmiCecSupported()
     }
     return false;
 }
+
+bool CECController::sendKey(uchar cecKeycode, cec_logical_address address)
+{
+    if (!m_cecAdapter->SendKeypress(address, static_cast<cec_user_control_code>(cecKeycode), true)) {
+        return false;
+    }
+    m_cecAdapter->SendKeyRelease(address);
+    return true;
+}
+
+bool CECController::powerOnDevices(cec_logical_address address)
+{
+    return m_cecAdapter->PowerOnDevices(address);
+}
+
+bool CECController::powerOffDevices(cec_logical_address address)
+{
+    return m_cecAdapter->StandbyDevices(address);
+}
+
+bool CECController::makeActiveSource()
+{
+    return m_cecAdapter->SetActiveSource();
+}
